{% load account_tags %}
{% user_display user as user_display %}

  <div class="forum-actions">
    <ul>
      {% if user.is_authenticated %}
      <a href="{% url app_forum-topic-add myforum.slug %}"class="btn btn-inverse"><i class="icon-folder-open"></i> {{ _('New topic') }}</a>
      {% endif %}
    </ul>
  </div>
